==> ejc-middlemeasurement-impl-3.0.0-20220525.141048-104-sources.jar: com/ejianc/business/middlemeasurement/vo/SubcontractvisadetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包经济签证月清确认子表
 * 
 * @author generator
 * 
 */
public class SubcontractvisadetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String subcontractingMode; // 分包方式
    private java.lang.String visaCode; // 签证编号
    private java.lang.String visaContent; // 签证主要内容
    private java.util.Date submissionDate; // 分包报送日期
    private java.math.BigDecimal submittedValue; // 报送值(元)
    private java.lang.Long visaagentId; // 签证经办人
    private java.lang.String visaagentName; // 签证经办人姓名
    private java.util.Date visaSubmissionDate; // 签证提交日期
    private java.util.Date approvalDate; // 项目部审批日期
    private java.math.BigDecimal exVisaAmount; // 签证金额(除税)(元)
    private java.math.BigDecimal inVisaAmount; // 签证金额(含税)(元)
    private java.math.BigDecimal exVisaOddjob; // 其中签证零工(除税)(元)
    private java.math.BigDecimal inVisaOddjob; // 其中签证零工(含税)(元)
    private java.math.BigDecimal totalDetail; // 合计(元)
    private java.lang.String unitSituation; // 分包签证转扣单位情况

    private java.lang.String submissionDateShow;//分包报送日期文本显示
    private java.lang.String visaSubmissionDateShow;//签证提交日期文本显示
    private java.lang.String approvalDateShow;//项目部审批日期文本显示

    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 分包方式
     */
    public java.lang.String getSubcontractingMode() {
        return subcontractingMode;
    }

    /**
     * 分包方式
     */
    public void setSubcontractingMode(java.lang.String subcontractingMode) {
        this.subcontractingMode = subcontractingMode;
    }
    /**
     * 签证编号
     */
    public java.lang.String getVisaCode() {
        return visaCode;
    }

    /**
     * 签证编号
     */
    public void setVisaCode(java.lang.String visaCode) {
        this.visaCode = visaCode;
    }
    /**
     * 签证主要内容
     */
    public java.lang.String getVisaContent() {
        return visaContent;
    }

    /**
     * 签证主要内容
     */
    public void setVisaContent(java.lang.String visaContent) {
        this.visaContent = visaContent;
    }
    /**
     * 分包报送日期
     */
    public java.util.Date getSubmissionDate() {
        return submissionDate;
    }

    /**
     * 分包报送日期
     */
    public void setSubmissionDate(java.util.Date submissionDate) {
        this.submissionDate = submissionDate;
    }
    /**
     * 报送值(元)
     */
    public java.math.BigDecimal getSubmittedValue() {
        return submittedValue;
    }

    /**
     * 报送值(元)
     */
    public void setSubmittedValue(java.math.BigDecimal submittedValue) {
        this.submittedValue = submittedValue;
    }
    /**
     * 签证经办人
     */
    public java.lang.Long getVisaagentId() {
        return visaagentId;
    }

    /**
     * 签证经办人
     */
    public void setVisaagentId(java.lang.Long visaagentId) {
        this.visaagentId = visaagentId;
    }
    /**
     * 签证经办人姓名
     */
    public java.lang.String getVisaagentName() {
        return visaagentName;
    }

    /**
     * 签证经办人姓名
     */
    public void setVisaagentName(java.lang.String visaagentName) {
        this.visaagentName = visaagentName;
    }
    /**
     * 签证提交日期
     */
    public java.util.Date getVisaSubmissionDate() {
        return visaSubmissionDate;
    }

    /**
     * 签证提交日期
     */
    public void setVisaSubmissionDate(java.util.Date visaSubmissionDate) {
        this.visaSubmissionDate = visaSubmissionDate;
    }
    /**
     * 项目部审批日期
     */
    public java.util.Date getApprovalDate() {
        return approvalDate;
    }

    /**
     * 项目部审批日期
     */
    public void setApprovalDate(java.util.Date approvalDate) {
        this.approvalDate = approvalDate;
    }
    /**
     * 签证金额(除税)(元)
     */
    public java.math.BigDecimal getExVisaAmount() {
        return exVisaAmount;
    }

    /**
     * 签证金额(除税)(元)
     */
    public void setExVisaAmount(java.math.BigDecimal exVisaAmount) {
        this.exVisaAmount = exVisaAmount;
    }
    /**
     * 签证金额(含税)(元)
     */
    public java.math.BigDecimal getInVisaAmount() {
        return inVisaAmount;
    }

    /**
     * 签证金额(含税)(元)
     */
    public void setInVisaAmount(java.math.BigDecimal inVisaAmount) {
        this.inVisaAmount = inVisaAmount;
    }
    /**
     * 其中签证零工(除税)(元)
     */
    public java.math.BigDecimal getExVisaOddjob() {
        return exVisaOddjob;
    }

    /**
     * 其中签证零工(除税)(元)
     */
    public void setExVisaOddjob(java.math.BigDecimal exVisaOddjob) {
        this.exVisaOddjob = exVisaOddjob;
    }
    /**
     * 其中签证零工(含税)(元)
     */
    public java.math.BigDecimal getInVisaOddjob() {
        return inVisaOddjob;
    }

    /**
     * 其中签证零工(含税)(元)
     */
    public void setInVisaOddjob(java.math.BigDecimal inVisaOddjob) {
        this.inVisaOddjob = inVisaOddjob;
    }
    /**
     * 合计(元)
     */
    public java.math.BigDecimal getTotalDetail() {
        return totalDetail;
    }

    /**
     * 合计(元)
     */
    public void setTotalDetail(java.math.BigDecimal totalDetail) {
        this.totalDetail = totalDetail;
    }
    /**
     * 分包签证转扣单位情况
     */
    public java.lang.String getUnitSituation() {
        return unitSituation;
    }

    /**
     * 分包签证转扣单位情况
     */
    public void setUnitSituation(java.lang.String unitSituation) {
        this.unitSituation = unitSituation;
    }

    public String getSubmissionDateShow() {
        return submissionDateShow;
    }

    public void setSubmissionDateShow(String submissionDateShow) {
        this.submissionDateShow = submissionDateShow;
    }

    public String getVisaSubmissionDateShow() {
        return visaSubmissionDateShow;
    }

    public void setVisaSubmissionDateShow(String visaSubmissionDateShow) {
        this.visaSubmissionDateShow = visaSubmissionDateShow;
    }

    public String getApprovalDateShow() {
        return approvalDateShow;
    }

    public void setApprovalDateShow(String approvalDateShow) {
        this.approvalDateShow = approvalDateShow;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/vo/SubcontractvisadetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;


/**
 * 分包经济签证月清确认子表
 * 
 * @author generator
 * 
 */
public class SubcontractvisadetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String subcontractingMode; // 分包方式
    private java.lang.String visaCode; // 签证编号
    private java.lang.String visaContent; // 签证主要内容
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date submissionDate; // 分包报送日期
    private java.math.BigDecimal submittedValue; // 报送值(元)
    private java.lang.Long visaagentId; // 签证经办人
    private java.lang.String visaagentName; // 签证经办人姓名
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date visaSubmissionDate; // 签证提交日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date approvalDate; // 项目部审批日期
    private java.math.BigDecimal exVisaAmount; // 签证金额(除税)(元)
    private java.math.BigDecimal inVisaAmount; // 签证金额(含税)(元)
    private java.math.BigDecimal exVisaOddjob; // 其中签证零工(除税)(元)
    private java.math.BigDecimal inVisaOddjob; // 其中签证零工(含税)(元)
    private java.math.BigDecimal totalDetail; // 合计(元)
    private java.lang.String unitSituation; // 分包签证转扣单位情况

    private java.lang.String submissionDateShow;//分包报送日期文本显示
    private java.lang.String visaSubmissionDateShow;//签证提交日期文本显示
    private java.lang.String approvalDateShow;//项目部审批日期文本显示

    public BigDecimal getTaxVisaAmount() {
        return taxVisaAmount;
    }

    public void setTaxVisaAmount(BigDecimal taxVisaAmount) {
        this.taxVisaAmount = taxVisaAmount;
    }

    public BigDecimal getTaxCasualLabour() {
        return taxCasualLabour;
    }

    public void setTaxCasualLabour(BigDecimal taxCasualLabour) {
        this.taxCasualLabour = taxCasualLabour;
    }

    private java.math.BigDecimal taxVisaAmount; // 签证金额(税金)(元)
    private java.math.BigDecimal taxCasualLabour; // 期中签证零工(税金)(元)



    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 分包方式
     */
    public java.lang.String getSubcontractingMode() {
        return subcontractingMode;
    }

    /**
     * 分包方式
     */
    public void setSubcontractingMode(java.lang.String subcontractingMode) {
        this.subcontractingMode = subcontractingMode;
    }
    /**
     * 签证编号
     */
    public java.lang.String getVisaCode() {
        return visaCode;
    }

    /**
     * 签证编号
     */
    public void setVisaCode(java.lang.String visaCode) {
        this.visaCode = visaCode;
    }
    /**
     * 签证主要内容
     */
    public java.lang.String getVisaContent() {
        return visaContent;
    }

    /**
     * 签证主要内容
     */
    public void setVisaContent(java.lang.String visaContent) {
        this.visaContent = visaContent;
    }
    /**
     * 分包报送日期
     */
    public java.util.Date getSubmissionDate() {
        return submissionDate;
    }

    /**
     * 分包报送日期
     */
    public void setSubmissionDate(java.util.Date submissionDate) {
        this.submissionDate = submissionDate;
    }
    /**
     * 报送值(元)
     */
    public java.math.BigDecimal getSubmittedValue() {
        return submittedValue;
    }

    /**
     * 报送值(元)
     */
    public void setSubmittedValue(java.math.BigDecimal submittedValue) {
        this.submittedValue = submittedValue;
    }
    /**
     * 签证经办人
     */
    public java.lang.Long getVisaagentId() {
        return visaagentId;
    }

    /**
     * 签证经办人
     */
    public void setVisaagentId(java.lang.Long visaagentId) {
        this.visaagentId = visaagentId;
    }
    /**
     * 签证经办人姓名
     */
    public java.lang.String getVisaagentName() {
        return visaagentName;
    }

    /**
     * 签证经办人姓名
     */
    public void setVisaagentName(java.lang.String visaagentName) {
        this.visaagentName = visaagentName;
    }
    /**
     * 签证提交日期
     */
    public java.util.Date getVisaSubmissionDate() {
        return visaSubmissionDate;
    }

    /**
     * 签证提交日期
     */
    public void setVisaSubmissionDate(java.util.Date visaSubmissionDate) {
        this.visaSubmissionDate = visaSubmissionDate;
    }
    /**
     * 项目部审批日期
     */
    public java.util.Date getApprovalDate() {
        return approvalDate;
    }

    /**
     * 项目部审批日期
     */
    public void setApprovalDate(java.util.Date approvalDate) {
        this.approvalDate = approvalDate;
    }
    /**
     * 签证金额(除税)(元)
     */
    public java.math.BigDecimal getExVisaAmount() {
        return exVisaAmount;
    }

    /**
     * 签证金额(除税)(元)
     */
    public void setExVisaAmount(java.math.BigDecimal exVisaAmount) {
        this.exVisaAmount = exVisaAmount;
    }
    /**
     * 签证金额(含税)(元)
     */
    public java.math.BigDecimal getInVisaAmount() {
        return inVisaAmount;
    }

    /**
     * 签证金额(含税)(元)
     */
    public void setInVisaAmount(java.math.BigDecimal inVisaAmount) {
        this.inVisaAmount = inVisaAmount;
    }
    /**
     * 其中签证零工(除税)(元)
     */
    public java.math.BigDecimal getExVisaOddjob() {
        return exVisaOddjob;
    }

    /**
     * 其中签证零工(除税)(元)
     */
    public void setExVisaOddjob(java.math.BigDecimal exVisaOddjob) {
        this.exVisaOddjob = exVisaOddjob;
    }
    /**
     * 其中签证零工(含税)(元)
     */
    public java.math.BigDecimal getInVisaOddjob() {
        return inVisaOddjob;
    }

    /**
     * 其中签证零工(含税)(元)
     */
    public void setInVisaOddjob(java.math.BigDecimal inVisaOddjob) {
        this.inVisaOddjob = inVisaOddjob;
    }
    /**
     * 合计(元)
     */
    public java.math.BigDecimal getTotalDetail() {
        return totalDetail;
    }

    /**
     * 合计(元)
     */
    public void setTotalDetail(java.math.BigDecimal totalDetail) {
        this.totalDetail = totalDetail;
    }
    /**
     * 分包签证转扣单位情况
     */
    public java.lang.String getUnitSituation() {
        return unitSituation;
    }

    /**
     * 分包签证转扣单位情况
     */
    public void setUnitSituation(java.lang.String unitSituation) {
        this.unitSituation = unitSituation;
    }

    public String getSubmissionDateShow() {
        return submissionDateShow;
    }

    public void setSubmissionDateShow(String submissionDateShow) {
        this.submissionDateShow = submissionDateShow;
    }

    public String getVisaSubmissionDateShow() {
        return visaSubmissionDateShow;
    }

    public void setVisaSubmissionDateShow(String visaSubmissionDateShow) {
        this.visaSubmissionDateShow = visaSubmissionDateShow;
    }

    public String getApprovalDateShow() {
        return approvalDateShow;
    }

    public void setApprovalDateShow(String approvalDateShow) {
        this.approvalDateShow = approvalDateShow;
    }
}
